@@ -54,13 +54,37 @@ def create_scaffold(project_name):
     create_folder(project_name)
     create_folder(os.path.join(project_name, "common"))
     create_file(os.path.join(project_name, "common", "__init__.py"))
+    data_maker_content = """import os
+
+import yaml
+from loguru import logger
+
+from common.handle_path import API_DATA_DIR, SCENARIO_DATA_DIR
+
+
+def _load_yaml(yaml_file):
+    with open(yaml_file, encoding='utf-8') as f:
+        yaml_testcase = yaml.safe_load(f)
+    return yaml_testcase
+
+
+def data_maker(class_name, method_name, file_path, model='scenario'):
+    api_data_path = API_DATA_DIR
+    scenario_data_path = SCENARIO_DATA_DIR
+    real_path = api_data_path if model == 'api' else scenario_data_path
+    yaml_path = os.path.join(real_path, file_path)
+    if not os.path.exists(yaml_path):
+        logger.error(f'{yaml_path} 不存在！')
+        raise
+    data = _load_yaml(yaml_path).get(class_name).get(method_name)
+    return data
+        """
+    create_file(os.path.join(project_name, "common", "data_maker.py"), data_maker_content)
     base_api_content = """import os
 import requests
 from loguru import logger
 
-from common.handle_path import CONF_DIR
 from common.utils import Utils
-from common.handle_assert import HandleAssert
 
 
 class BaseApi:
@@ -117,28 +141,110 @@ class BaseApi:
         logger.info(f"请求参数：{params}")
         logger.info(f"请求体：{json}")
         logger.info(f"请求表单数据：{data}")
-    
-    @staticmethod
-    def assert_equal(ex, re):
-        \"""
-        断言相等
-        :param ex:预期结果
-        :param re:实际结果
-        :return:
-        \"""
-        return HandleAssert.eq(ex, re)
 
-    @staticmethod
-    def assert_contains(content, target):
-        \"""
-        断言包含
-        :param content: 文本内容
-        :param target: 目标文本
-        :return:
-        \"""
-        return HandleAssert.contains(content, target)
     """
     create_file(os.path.join(project_name, "common", "base_api.py"), base_api_content)
+    base_testcase_content = """from typing import Text, NoReturn
+
+from jsonpath import jsonpath
+from loguru import logger
+
+from service.params_pool import ParamsPool
+
+
+class BaseTestcase:
+    @staticmethod
+    def extract_set_vars(res, var_name: Text, expr: Text, index=None) -> NoReturn:
+        \"""
+        提取响应结果中的变量并设置为参数池属性
+        :param res: the json-encoded content of response
+        :param var_name:
+        :param expr: jsonpath expr
+        :param index: jsonpath result index
+        :return:
+        \"""
+        index = index if index else 0
+        extract_variable = jsonpath(res, expr)[index]
+        setattr(ParamsPool().Vars, var_name, extract_variable)
+
+    @staticmethod
+    def eq(actual_value, expected_value):
+        \"""
+        equals
+        \"""
+        try:
+            assert actual_value == expected_value
+        except AssertionError as e:
+            logger.error(f"eq断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def gt(actual_value, expected_value):
+        \"""
+        greater than
+        \"""
+        try:
+            assert actual_value > expected_value
+        except AssertionError as e:
+            logger.error(f"gt断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def lt(actual_value, expected_value):
+        \"""
+        less than
+        \"""
+        try:
+            assert actual_value < expected_value
+        except AssertionError as e:
+            logger.error(f"lt断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def neq(actual_value, expected_value):
+        \"""
+        not equals
+        \"""
+        try:
+            assert actual_value != expected_value
+        except AssertionError as e:
+            logger.error(f"neq断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def ge(actual_value, expected_value):
+        \"""
+        greater than or equals
+        \"""
+        try:
+            assert actual_value >= expected_value
+        except AssertionError as e:
+            logger.error(f"ge断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def le(actual_value, expected_value):
+        \"""
+        less than or equals
+        ""\"
+        try:
+            assert actual_value <= expected_value
+        except AssertionError as e:
+            logger.error(f"le断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+
+    @staticmethod
+    def contains(actual_value, expected_value):
+        assert isinstance(
+            expected_value, (list, tuple, dict, str, bytes)
+        ), "expect_value should be list/tuple/dict/str/bytes type"
+        try:
+            assert expected_value in actual_value
+        except AssertionError as e:
+            logger.error(f"contains断言失败，预期结果：{expected_value}，实际结果：{actual_value}")
+            raise e
+    """
+    create_file(os.path.join(project_name, "common", "base_testcase.py"), base_testcase_content)
     handle_path_content = """import os
 
 # 项目根目录
@@ -147,7 +253,9 @@ BASEDIR = os.path.dirname(os.path.dirname(__file__))
 CONF_DIR = os.path.join(BASEDIR, "conf")
 CONFIG_DIR = os.path.join(CONF_DIR, 'config.yaml')
 # 用例数据的目录
-DATA_DIR = os.path.join(BASEDIR, "datas")
+DATA_DIR = os.path.join(BASEDIR, "data")
+API_DATA_DIR = os.path.join(DATA_DIR, "api_data")
+SCENARIO_DATA_DIR = os.path.join(DATA_DIR, "scenario_data")
 # 日志文件目录
 LOG_DIR = os.path.join(BASEDIR, "log")
 # 测试报告的路
@@ -199,21 +307,22 @@ class Utils:
     create_file(os.path.join(project_name, "common", "utils.py"), utils_content)
     wrapper_content = """from loguru import logger
 
-
-def api_call(func):
-    \"""
-    接口调用记录
-    :param func: 装饰的函数
-    :return:
-    \"""
-
-    def inner(*args, **kwargs):
-        logger.info(f"开始调用接口：{func.__name__}")
+def basic_assert(func):
+    \"""接口调用记录，基础断言""\"
+    def wrapper(*args, **kwargs):
+        func_name = func.__name__
+        logger.info(f"【开始调用接口：{func_name}】")
         res = func(*args, **kwargs)
-        logger.info(f"结束调用接口：{func.__name__}")
+        try:
+            assert res['ret_code'] == 0
+        except AssertionError as e:
+            logger.error(f'ret_code不为0，请检查.ao:{func_name},result:{res}')
+            raise e
+        finally:
+            logger.info(f"【结束调用接口：{func_name}】")
         return res
 
-    return inner
+    return wrapper
     """
     create_file(os.path.join(project_name, "common", "wrapper.py"), wrapper_content)
     mysql_content = """import os
@@ -262,43 +371,8 @@ class HandleMysql:
         self.con.close()
     """
     create_file(os.path.join(project_name, "common", "handle_mysql.py"), mysql_content)
-    assert_content = """from loguru import logger
-
-
-class HandleAssert:
-
-    @staticmethod
-    def eq(ex, re):
-        \"""
-        断言相等
-        :param ex: 预期结果
-        :param re: 实际结果
-        :return:
-        \"""
-        try:
-            assert str(ex) == str(re)
-        except AssertionError as e:
-            logger.error(f"eq断言失败，预期结果：{ex}，实际结果：{re}")
-            logger.error("用例失败！")
-            raise e
-
-    @staticmethod
-    def contains(content, target):
-        \"""
-        断言包含
-        :param content: 文本内容
-        :param target: 目标文本
-        :return:
-        \"""
-        try:
-            assert str(content) in str(target)
-        except AssertionError as e:
-            logger.error(f"contains断言失败，目标文本{target}包含 文本{content}")
-            raise e
-    """
-    create_file(os.path.join(project_name, "common", "handle_assert.py"), assert_content)
+    create_folder(os.path.join(project_name, "flow2yaml"))
     create_folder(os.path.join(project_name, "apis"))
-    # TODO: check
     create_file(os.path.join(project_name, "apis", "__init__.py"))
     demo_api_content = """import json
     
@@ -345,6 +419,9 @@ class ParamsPool(BaseApi):
 
     def init_common_params(self):
         setattr(self, 'name', 'test')
+        
+    class Vars:
+        pass
     """
     create_file(os.path.join(project_name, "service", "params_pool.py"), params_pool_content)
     func_pool_content = """from common.base_api import BaseApi
@@ -420,11 +497,11 @@ def login(env_vars):
 @pytest.fixture(scope='session', autouse=True)
 def handle_headers(login):
     resp_login = login
-    headers = {'Cookie': f'csrftoken={resp_login["csrftoken"]};sid={resp_login["sid"]};sk={resp_login["sk"]}',
-               'X-CSRFToken': resp_login["csrftoken"]}
+    headers = {'Cookie': "cookie"}
     setattr(BaseApi, 'headers', headers)
     logger.info(f'设置全局请求头:{headers}')
 
+
 @pytest.fixture(scope='session', autouse=True)
 def make_params():
     logger.info('开始生成公共参数')
@@ -433,6 +510,50 @@ def make_params():
     logger.info('******************************全局前置条件配置完成******************************')
     """
     create_file(os.path.join(project_name, "fixtures", "fixture_login.py"), fixture_login_content)
+    fixture_report_content = """from datetime import datetime
+
+import pytest
+from loguru import logger
+from py._xmlgen import html
+
+
+@pytest.mark.hookwrapper
+def pytest_runtest_makereport(item):
+    pytest_html = item.config.pluginmanager.getplugin('html')
+    outcome = yield
+    report = outcome.get_result()
+    extra = getattr(report, 'extra', [])
+    report.extra = extra
+    report.description = str(item.function.__doc__)
+    report.nodeid = report.nodeid.encode("utf-8").decode("unicode_escape")  # 设置编码显示中文
+
+
+@pytest.mark.optionalhook
+def pytest_html_results_summary(prefix, summary, postfix):
+    prefix.extend([html.p("测试人: Listen's Robot")])
+
+
+@pytest.mark.optionalhook
+def pytest_html_results_table_header(cells):
+    cells.insert(1, html.th('Description'))
+    cells.pop(2)
+    cells.insert(3, html.th('Time', class_='sortable time', col='time'))
+    cells.pop()
+
+
+@pytest.mark.optionalhook
+def pytest_html_results_table_row(report, cells):
+    if report.outcome == 'passed':
+        cells.clear()
+        return 
+    cells.insert(1, html.td(report.description))
+    cells.pop(2)
+    cells[2] = html.td(f"{report.duration:.2f}s")
+    cells.insert(3, html.td(datetime.now(), class_='col-time'))
+    cells.pop()
+    logger.warning(report.outcome)
+    """
+    create_file(os.path.join(project_name, "fixtures", "fixture_report.py"), fixture_report_content)
     create_folder(os.path.join(project_name, "conf"))
     config_content = """env: test
 test:
@@ -464,8 +585,13 @@ for root, _, files in os.walk(FIXTURE_DIR):
                     pass
     """
     create_file(os.path.join(project_name, "conftest.py"), conftest_content)
-    run_content = """import pytest
-pytest.main(['-s', '-m demo'])
+    run_content = """import os
+    
+import pytest
+
+pytest.main(['-s', '-m demo', r"--alluredir=report/json", "--clean-alluredir", "--html=report/aomaker_report.html",
+             "--self-contained-html", "--capture=sys"])
+os.system('allure generate ./report/json -o ./report/html -c')
     """
     create_file(os.path.join(project_name, "run.py"), run_content)
     pytest_ini_content = """[pytest]
@@ -474,68 +600,71 @@ markers =
     regress: regress test
     """
     create_file(os.path.join(project_name, "pytest.ini"), pytest_ini_content)
-    create_folder(os.path.join(project_name, "data"))
-    datas_content = """job:
-  submit_hpc_job:
-    - title: '验证提交hpc作业-共享队列-sleep'
-      variables:
-        cmd_line_type: 'input'  # select
-        cmd_line: 'sleep 10'
-        name: 'sleep_auto'
-        core_limit: 5
-        software: ''
-        queue_type: 'share_queue'
-      expected: {"ret_code": 0}
-    - title: '验证提交hpc作业-共享队列-普通脚本'
-      variables:
-        cmd_line_type: 'select'  # select
-        input_file: 'work.sh'
-        stdout_redirect_path: ''
-        stderr_redirect_path: ''
-        name: 'script_auto'
-        core_limit: 5
-        software: ''
-        queue_type: 'share_queue'
-      expected: {"ret_code": 0}
-    """
-    create_file(os.path.join(project_name, "data", "api_datas.yaml"), datas_content)
-    datas_content = """hpc_smoke:
-  - title: 'hpc冒烟用例'
-    step:
-      create_hpc_cluster:
-        cluster_name: 'auto_hpc'
-      add_nodes:
-        cluster_type: 'hpc'
-        node_role: 'login'
-      submit_hpc_job:
-        'cmd_line_type': 'input'
-        'cmd_line': 'sleep 10'
-        'name': 'sleep_auto'
-        'core_limit': 5
-        'software': ''
-        'queue_type': 'share_queue'
-      
-ehpc_smoke:
-  - title: 'ehpc冒烟用例'
-    step:
-      create_ehpc_cluster:
-        cluster_name: 'auto_hpc'
-      add_nodes:
-        login:
-          cluster_type: 'ehpc'
-          node_role: 'login'
-        compute:
-          cluster_type: 'ehpc'
-          node_role: 'compute'
-      submit_ehpc_job:
-        'cmd_line_type': 'input'
-        'cmd_line': 'sleep 10'
-        'name': 'sleep_auto'
-        'core_limit': 5
-        'software': ''
-        'queue_type': 'share_queue'
-    """
-    create_file(os.path.join(project_name, "data", "case_datas.yaml"), datas_content)
+    data_path = os.path.join(project_name, "data")
+    create_folder(data_path)
+    create_folder(os.path.join(data_path, "api_data"))
+    create_folder(os.path.join(data_path, "scenario_data"))
+    #     datas_content = """job:
+    #   submit_hpc_job:
+    #     - title: '验证提交hpc作业-共享队列-sleep'
+    #       variables:
+    #         cmd_line_type: 'input'  # select
+    #         cmd_line: 'sleep 10'
+    #         name: 'sleep_auto'
+    #         core_limit: 5
+    #         software: ''
+    #         queue_type: 'share_queue'
+    #       expected: {"ret_code": 0}
+    #     - title: '验证提交hpc作业-共享队列-普通脚本'
+    #       variables:
+    #         cmd_line_type: 'select'  # select
+    #         input_file: 'work.sh'
+    #         stdout_redirect_path: ''
+    #         stderr_redirect_path: ''
+    #         name: 'script_auto'
+    #         core_limit: 5
+    #         software: ''
+    #         queue_type: 'share_queue'
+    #       expected: {"ret_code": 0}
+    #     """
+    #     create_file(os.path.join(project_name, "data", "job_datas.yaml"), datas_content)
+    #     datas_content = """hpc_smoke:
+    #   - title: 'hpc冒烟用例'
+    #     step:
+    #       create_hpc_cluster:
+    #         cluster_name: 'auto_hpc'
+    #       add_nodes:
+    #         cluster_type: 'hpc'
+    #         node_role: 'login'
+    #       submit_hpc_job:
+    #         'cmd_line_type': 'input'
+    #         'cmd_line': 'sleep 10'
+    #         'name': 'sleep_auto'
+    #         'core_limit': 5
+    #         'software': ''
+    #         'queue_type': 'share_queue'
+    #
+    # ehpc_smoke:
+    #   - title: 'ehpc冒烟用例'
+    #     step:
+    #       create_ehpc_cluster:
+    #         cluster_name: 'auto_hpc'
+    #       add_nodes:
+    #         login:
+    #           cluster_type: 'ehpc'
+    #           node_role: 'login'
+    #         compute:
+    #           cluster_type: 'ehpc'
+    #           node_role: 'compute'
+    #       submit_ehpc_job:
+    #         'cmd_line_type': 'input'
+    #         'cmd_line': 'sleep 10'
+    #         'name': 'sleep_auto'
+    #         'core_limit': 5
+    #         'software': ''
+    #         'queue_type': 'share_queue'
+    #     """
+    #     create_file(os.path.join(project_name, "data", "case_datas.yaml"), datas_content)
     create_folder(os.path.join(project_name, "report"))
 
     return 0
